==> unswamp-1.0.7.1.5-py3-none-any.whl: unswamp/checks/base/BaseCheck.py <==
import logging as log
from datetime import datetime

from unswamp.objects import CheckResult


class BaseCheck:
    _settings = {}
    ##################################################################################################
    # Constructor
    ##################################################################################################

    def __init__(self, id, check_meta_data=None):
        self.id = id
        if check_meta_data is None:
            check_meta_data = {}
        self.check_meta_data = check_meta_data

    ##################################################################################################
    # Methods
    ##################################################################################################
    def run(self, dataset):
        start = datetime.now()
        log.debug(f"start run check '{self.check_name}' with id '{self.id}'")
        passed, message = self._run(dataset)
        passed = bool(passed)
        end = datetime.now()
        result = CheckResult(self, start, end, passed, message)
        log.debug(result)
        log.debug(f"stop run check '{self.check_name}' with id '{self.id}'")
        return result

    ##################################################################################################
    # Properties
    ##################################################################################################
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value

    @property
    def check_name(self):
        check_name = self.__class__.__name__
        return check_name

    @property
    def check_meta_data(self):
        return self._check_meta_data

    @check_meta_data.setter
    def check_meta_data(self, value):
        self._check_meta_data = value
        self._settings["check_meta_data"] = value

    @property
    def settings(self):
        return self._settings

==> unswamp-1.0.7.1.7-py3-none-any.whl: unswamp/checks/base/BaseCheck.py <==
from datetime import datetime

from unswamp.objects import CheckResult
from ..Functions import Functions
from ..Descriptions import Descriptions


class BaseCheck:
    ##################################################################################################
    # Constructor
    ##################################################################################################

    def __init__(self, check_id, meta_data=None, level="column"):
        self.id = check_id
        if meta_data is None:
            meta_data = {}
        self.meta_data = meta_data
        self.level = level
        self.description = None
        self.name = self.__class__.__name__

    ##################################################################################################
    # Methods
    ##################################################################################################

    def run(self, dataset):
        start = datetime.now()
        passed, message = self._run(dataset)
        passed = bool(passed)
        end = datetime.now()
        result = CheckResult(self, start, end, passed, message)
        return result

    ##################################################################################################
    # Properties
    ##################################################################################################
    id = None
    meta_data = {}
    level = "column"
    name = None

    ##################################################################################################
    # ReadOnly Properties
    ##################################################################################################
    @property
    def description(self):
        self.description = Descriptions.get_check_description(self.name, self.__dict__)


    @description.setter
    def description(self, value):
        self._description = value
